﻿using System;
using System.Collections.ObjectModel;

namespace Infragistics.SampleGrid.Sources
{
    public class TestDataSourceTwo : ObservableCollection<TestCategory>
    {
        public event EventHandler Completed;
        private TestDataLoader loader;
        private int? _maxItems = null;

        #region Constructors
        public TestDataSourceTwo()
        {
            loader = new TestDataLoader();
            loader.Completed += new EventHandler(loader_Completed);
        }

        public TestDataSourceTwo(bool beginDataLoad)
        {
            loader = new TestDataLoader();
            loader.Completed += new EventHandler(loader_Completed);

            if (beginDataLoad)
                LoadData();
        }

        public TestDataSourceTwo(bool beginDataLoad, int maxItems)
        {
            _maxItems = maxItems;
            loader = new TestDataLoader();
            loader.Completed += new EventHandler(loader_Completed);

            if (beginDataLoad)
                LoadData();
        }
        #endregion

        #region Public methods
        public void LoadData()
        {
            loader.BeginLoading();
        }
        #endregion

        #region Event handlers
        void loader_Completed(object sender, EventArgs e)
        {
            int count = 0;
            foreach (TestCategory cat in loader.Data)
            {
                if (_maxItems != null && count >= _maxItems)
                    break;
                this.Add(cat);
                count++;
            }

            if (Completed != null)
                Completed(this, new EventArgs());
        }
        #endregion
    }
}
